@@ -4,9 +4,9 @@ import sys
 from packaging.markers import default_environment
 from packaging.requirements import Requirement
 
-try:
+if sys.version_info >= (3, 8):
     from importlib.metadata import Distribution, DistributionFinder
-except ImportError:  # no cov
+else:
     from importlib_metadata import Distribution, DistributionFinder
 
 
@@ -86,10 +86,10 @@ def dependency_in_sync(requirement, environment, installed_distributions):
 
                 # Try a few variations, see:
                 # https://peps.python.org/pep-0440/#direct-references
-                if requirement.url != '{}+{}@{}'.format(vcs, url, commit_id):
+                if requirement.url != f'{vcs}+{url}@{commit_id}':
                     if 'requested_revision' in vcs_info:
                         requested_revision = vcs_info['requested_revision']
-                        if requirement.url != '{}+{}@{}#{}'.format(vcs, url, requested_revision, commit_id):
+                        if requirement.url != f'{vcs}+{url}@{requested_revision}#{commit_id}':
                             return False
                     else:
                         return False
